==> rong-ui-react-0.0.1.tgz: package/es/titlebar/titlebar.js <==
import React, { memo } from 'react';
import PropTypes from 'prop-types';
import './style/titlebar.less';
var prefixCls = 'r-titlebar';
var Titlebar = /*#__PURE__*/memo(function (_ref) {
  var theme = _ref.theme,
      l = _ref.l,
      c = _ref.c,
      r = _ref.r,
      children = _ref.children,
      showBackto = _ref.showBackto,
      backArrowStyle = _ref.backArrowStyle,
      onBack = _ref.onBack,
      className = _ref.className;
  var wrapCls = [prefixCls, "".concat(prefixCls, "-theme-").concat(theme), className].filter(Boolean).join(' ');
  var arrowStyle = backArrowStyle ? backArrowStyle : {
    color: /^(b|c|d|e|f)$/.test(theme) ? '#fff' : '#333'
  };
  console.log('Titlebar mounted or updated');
  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls
  }, showBackto && /*#__PURE__*/React.createElement("div", {
    className: "l-operate",
    onClick: function onClick(e) {
      return onBack && onBack(e);
    }
  }, l ? l : /*#__PURE__*/React.createElement("div", {
    className: "back"
  }, /*#__PURE__*/React.createElement("svg", {
    width: "10px",
    height: "21px",
    style: arrowStyle,
    viewBox: "0 0 10 21",
    version: "1.1",
    xmlns: "http://www.w3.org/2000/svg",
    xmlnsXlink: "http://www.w3.org/1999/xlink"
  }, /*#__PURE__*/React.createElement("g", {
    stroke: "none",
    strokeWidth: "1",
    fill: "none",
    fillRule: "evenodd",
    strokeLinecap: "round"
  }, /*#__PURE__*/React.createElement("g", {
    transform: "translate(-16.000000, -33.000000)",
    stroke: arrowStyle.color
  }, /*#__PURE__*/React.createElement("polyline", {
    id: "Path-2",
    points: "25.758131 34 16 43.3837058 26 53"
  })))))), c || children, /*#__PURE__*/React.createElement("div", {
    className: "r-operate"
  }, r));
});
Titlebar.defaultProps = {
  theme: 'a',
  showBackto: true
};
Titlebar.propTypes = {
  theme: PropTypes.string,
  showBackto: PropTypes.bool,
  backArrowStyle: PropTypes.object
};
export default Titlebar;

==> rong-ui-react-0.0.3.tgz: package/es/titlebar/titlebar.js <==
import React, { memo } from 'react';
import PropTypes from 'prop-types';
var prefixCls = 'r-titlebar';
var Titlebar = /*#__PURE__*/memo(function (_ref) {
  var theme = _ref.theme,
      l = _ref.l,
      title = _ref.title,
      r = _ref.r,
      children = _ref.children,
      showBackto = _ref.showBackto,
      backArrowStyle = _ref.backArrowStyle,
      onBack = _ref.onBack,
      className = _ref.className;
  var wrapCls = [prefixCls, "".concat(prefixCls, "-theme-").concat(theme), className].filter(Boolean).join(' ');
  console.log('Titlebar mounted or updated');
  return /*#__PURE__*/React.createElement("div", {
    className: wrapCls
  }, showBackto && /*#__PURE__*/React.createElement("div", {
    className: "l-operate",
    onClick: function onClick(e) {
      return onBack && onBack(e);
    }
  }, l ? l : /*#__PURE__*/React.createElement("div", {
    className: "back"
  }, /*#__PURE__*/React.createElement("svg", {
    width: "10px",
    height: "21px",
    style: backArrowStyle,
    viewBox: "0 0 10 21",
    version: "1.1"
  }, /*#__PURE__*/React.createElement("g", {
    stroke: "none",
    strokeWidth: "1",
    fill: "none",
    fillRule: "evenodd",
    strokeLinecap: "round"
  }, /*#__PURE__*/React.createElement("g", {
    transform: "translate(-16.000000, -33.000000)",
    stroke: "currentColor"
  }, /*#__PURE__*/React.createElement("polyline", {
    id: "Path-2",
    points: "25.758131 34 16 43.3837058 26 53"
  })))))), /*#__PURE__*/React.createElement("div", {
    className: "c-operate"
  }, title || children), r && /*#__PURE__*/React.createElement("div", {
    className: "r-operate"
  }, r));
});
Titlebar.defaultProps = {
  theme: 'a',
  showBackto: true
};
Titlebar.propTypes = {
  theme: PropTypes.string,
  showBackto: PropTypes.bool,
  backArrowStyle: PropTypes.object
};
export default Titlebar;
